@@ -86,7 +86,7 @@ pub enum WebhookParseErrorType {
 /// let url = "https://canary.discord.com/api/webhooks/794590023369752587/tjxHaPHLKp9aEdSwJuLeHhHHGEqIxt1aay4I67FOP9uzsYEWmj0eJmDn-2ZvCYLyOb_K";
 ///
 /// let (id, token) = webhook::parse(url)?;
-/// assert_eq!(WebhookId(794590023369752587), id);
+/// assert_eq!(WebhookId::new(794590023369752587).expect("non zero"), id);
 /// assert_eq!(
 ///     Some("tjxHaPHLKp9aEdSwJuLeHhHHGEqIxt1aay4I67FOP9uzsYEWmj0eJmDn-2ZvCYLyOb_K"),
 ///     token,
@@ -104,7 +104,7 @@ pub enum WebhookParseErrorType {
 /// let url = "https://canary.discord.com/api/webhooks/794590023369752587";
 ///
 /// let (id, token) = webhook::parse(url)?;
-/// assert_eq!(WebhookId(794590023369752587), id);
+/// assert_eq!(WebhookId::new(794590023369752587).expect("non zero"), id);
 /// assert!(token.is_none());
 /// # Ok(()) }
 /// ```
@@ -167,13 +167,13 @@ mod tests {
     #[test]
     fn test_parse_no_token() {
         assert_eq!(
-            (WebhookId(123), None),
+            (WebhookId::new(123).expect("non zero"), None),
             super::parse("https://discord.com/api/webhooks/123").unwrap(),
         );
         // There's a / after the ID signifying another segment, but the token
         // ends up being None.
         assert_eq!(
-            (WebhookId(123), None),
+            (WebhookId::new(123).expect("non zero"), None),
             super::parse("https://discord.com/api/webhooks/123").unwrap(),
         );
         assert!(super::parse("https://discord.com/api/webhooks/123/")
@@ -186,24 +186,24 @@ mod tests {
     fn test_parse_with_token() {
         assert_eq!(
             super::parse("https://discord.com/api/webhooks/456/token").unwrap(),
-            (WebhookId(456), Some("token")),
+            (WebhookId::new(456).expect("non zero"), Some("token")),
         );
         // The value of the segment(s) after the token are ignored.
         assert_eq!(
             super::parse("https://discord.com/api/webhooks/456/token/github").unwrap(),
-            (WebhookId(456), Some("token")),
+            (WebhookId::new(456).expect("non zero"), Some("token")),
         );
         assert_eq!(
             super::parse("https://discord.com/api/webhooks/456/token/slack").unwrap(),
-            (WebhookId(456), Some("token")),
+            (WebhookId::new(456).expect("non zero"), Some("token")),
         );
         assert_eq!(
             super::parse("https://discord.com/api/webhooks/456/token/randomsegment").unwrap(),
-            (WebhookId(456), Some("token")),
+            (WebhookId::new(456).expect("non zero"), Some("token")),
         );
         assert_eq!(
             super::parse("https://discord.com/api/webhooks/456/token/one/two/three").unwrap(),
-            (WebhookId(456), Some("token")),
+            (WebhookId::new(456).expect("non zero"), Some("token")),
         );
     }
 
